#include <UniPWMControl.h>
#include <UniPWMMacros.h>

// Pins for LEDs
#define HEAT 3 // heat unit at PIN D3 using N-Mosfet
#define RECEIVER_INP 2 // receiver input signal not in use in this case
#define TESTDIODE 13 // Testdiode 13
#define LED 10 // monitor LED between D10 and source(-)


// constant lights: on, off, dimmmed (max 255)
SEQUENCE( constOn ) = { HOLD( 255 ) };
SEQUENCE( constOff ) = { HOLD( 0 ) };
SEQUENCE( dimmedOn ) = { HOLD( 100 ) };

// single flash 200ms, dark 1200ms
SEQUENCE( singleFlash ) = { PAUSE(10), CONST(255,3), PAUSE(160) };

// double flash 2x200ms, pause 800ms
//SEQUENCE( doubleFlash ) = { PAUSE(10), CONST(255,3), PAUSE(10), CONST(255,3), PAUSE(80) };

// beacon - 2 ramps up - hold - 2 ramps down
SEQUENCE( beacon ) = { RAMP(0,45,20), RAMP(45,255,20), CONST(255,20), RAMP(255,45,20), RAMP(45,0,20), PAUSE(20) };

UniPWMControl ctrl;

enum { PATTERN_STARTUP, PATTERN_HEAT, PATTERN_HOT, PATTERN_OFF }; // Name new pattern here...

void setup()
{
Serial.begin(9600);

// high level object
ctrl.Init( 10 ); // max 10 output channels
ctrl.SetLowBatt( 510, PATTERN_OFF ); // switch off (635 ~12,55 Volt, switch off value ~ 506 (3.3V bzw 10,0V gesamt) ueber Spannungsteiler + 8,2K Abgriff 2,7 K Masse an Pin A0
ctrl.SetInpChannelPin( RECEIVER_INP, UniPWMInpChannel::INP_NORMAL );

// Heat 
//ctrl.AddSequence( PATTERN_HEAT, TESTDIODE, ARRAY( beacon ) ); 
ctrl.AddSequence( PATTERN_HEAT, LED, ARRAY( beacon ) ); 
ctrl.AddSequence( PATTERN_HEAT, HEAT, ARRAY( constOn ) ); 

// off swiched off heater if very low batt
//ctrl.AddSequence( PATTERN_OFF, TESTDIODE, ARRAY( singleFlash ) ); 
ctrl.AddSequence( PATTERN_OFF, LED, ARRAY( singleFlash ) ); 
ctrl.AddSequence( PATTERN_OFF, HEAT, ARRAY( constOff ) ); 

// hot  to hot in case
//ctrl.AddSequence( PATTERN_HOT, TESTDIODE, ARRAY( dimmedOn ) ); 
ctrl.AddSequence( PATTERN_HOT, LED, ARRAY( dimmedOn ) ); 
ctrl.AddSequence( PATTERN_HOT, HEAT, ARRAY( constOff ) ); 

ctrl.AddInputSwitchPos( 0, 390, PATTERN_HOT );
ctrl.AddInputSwitchPos( 390, 1000, PATTERN_HEAT );

// initalize pattern "heat"
ctrl.ActivatePattern( PATTERN_HEAT ); 
}


void loop()
{
    ctrl.DoLoop( analogRead(A1));
  delay( 500 );
}

